@@ -106,7 +106,7 @@ class BigqueryHandler:
             query_job = self.client.query(query)
         return list(query_job.result())
 
-    def get_table(self, table_name):
+    def get_table_rows(self, table_name):
         return self.get_list_from_query(querystr=f'select * from {table_name}')
 
     def get_column_names(self, dataset_name, table_name):
